%global         __python %{__python3}



%define         major                         3
%define         libname                       %mklibname %{name} %{major}
%define         libdevelname                  %mklibname %{name} -d


%define         gccinstalldir   %(LC_ALL=C %__cc --print-search-dirs | grep install | %__awk '{print $2}')
%define         fincludedir     %{gccinstalldir}finclude


Name:           petsc
Summary:        A tools suite for partial differential equations
Version:        3.14.2
Release:        %mkrel 1
License:        BSD-like
Group:          System/Libraries
Url:            https://www.mcs.anl.gov/petsc/download/index.html
Source0:        http://ftp.mcs.anl.gov/pub/petsc/release-snapshots/%{name}-lite-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(ompi)
BuildRequires:  pkgconfig(hwloc)
BuildRequires:  pkgconfig(blas)
BuildRequires:  pkgconfig(lapack)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(mpfr)
BuildRequires:  pkgconfig(muparser)
BuildRequires:  pkgconfig(OpenCL)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(valgrind)
BuildRequires:  hdf5-devel
#look for static lib only
#BuildRequires:  sundials-devel
#BuildRequires:  suitesparse-devel
BuildRequires:  libgomp-devel
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  ptscotch-openmpi-devel
BuildRequires:  boost-devel
BuildRequires:  libcgns-devel
BuildRequires:  gmp-devel
BuildRequires:  yaml-devel
BuildRequires:  python3-mpi4py


%description
PETSc, pronounced PET-see (the S is silent), is a suite of data
structures and routines for the scalable (parallel) solution of
scientific applications modeled by partial differential equations. It
supports MPI, and GPUs through CUDA or OpenCL, as well as hybrid
MPI-GPU parallelism. PETSc (sometimes called PETSc/Tao) also contains
the Tao optimization software library.



%package -n %{libname}
Summary:        Shared objects for PETSc
Group:          System/Libraries
Provides:       lib%{name} = %{version}-%{release}

%description -n %{libname}
%{summary}


%package -n %{libdevelname}
Summary:        Development files for the PETSc library
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{libdevelname}
%{summary}.



%prep
%setup -q
%autopatch -p1



sed -i 's|#!/usr/bin/env python|#!/usr/bin/python3|g' config/*.py
sed -i 's|#!/usr/bin/env python|#!/usr/bin/python3|g' config/BuildSystem/*.py
sed -i 's|#!/usr/bin/env python|#!/usr/bin/python3|g' config/BuildSystem/config/*.py
sed -i 's|#!/usr/bin/env python|#!/usr/bin/python3|g' config/PETSc/options/*.py
sed -i 's|#!/usr/bin/env python|#!/usr/bin/python3|g' config/examples/*.py
sed -i 's|#!/usr/bin/env python|#!/usr/bin/python3|g' lib/petsc/bin/*.py
sed -i 's|#!/usr/bin/env python|#!/usr/bin/python3|g' lib/petsc/bin/petsc*
sed -i 's|#!/usr/bin/env python|#!/usr/bin/python3|g' lib/petsc/bin/saws/*.py

%build
#let's do this by hand, the configure script is home made
%before_configure
%_configure --CFLAGS="%{optflags}" --CXXFLAGS="%{optflags}"          \
            --FFLAGS="%{optflags} -fPIC" --LDFLAGS="%{ldflags}"      \
	    --prefix=%{_prefix} --with-avx512-kernels=0              \
            --with-python-exec=%{__python3}                          \
            --with-mpi=1 --with-openmp=1 --with-blaslapack=1         \
            --with-hwloc=1 --with-zlib --with-hdf5=1 --with-netcdf=1 \
	    --with-eigen=1 --with-suitesparse=0                      \
	    --with-ptscotch=1                                        \
	    --with-ptscotch-dir=%{_libdir}/mpi/gcc/openmpi           \
	    --with-boost=1 --with-cgns=1 --with-fftw=1               \
	    --with-gmp=1 --with-libjpeg=1 --with-mpfr=1              \
	    --with-muparser=1 --with-opencl=1                        \
	    --with-yaml=1 --with-zstd=1 --with-valgrind=1


%make_build

%install
%make_install

#the bloody /usr/lib is hardcoded everywhere
%if "%{?_lib}" == "lib64"
pushd %{buildroot}/%{_prefix}
%__mv -f lib %{_lib}
popd
%endif

#put fortran module files where they should
%__mkdir -p %{buildroot}/%{fincludedir}
%__mv -f %{buildroot}/%{_includedir}/*.mod %{buildroot}/%{fincludedir}/
sed -i 's|libdir=${prefix}/lib|libdir=${prefix}/%{_lib}|g' %{buildroot}/%{_libdir}/pkgconfig/PETSc.pc


%files -n %{name}
%doc LICENSE
%{_datadir}/petsc

%files -n %{libname}
%{_libdir}/libpetsc.so.%{major}{,.*}
%{_libdir}/petsc

%files -n %{libdevelname}
%{_includedir}/petsc*.h
%{_includedir}/petscvec.hpp
%{fincludedir}/*.mod
%{_includedir}/petsc
%{_includedir}/ftn-auto/petscloghf.c
%{_libdir}/libpetsc.so
%{_libdir}/pkgconfig/*.pc


%changelog
* Sun Dec 06 2020 eatdirt <eatdirt> 3.14.2-1.mga8
+ Revision: 1653751
- Upgrade to version 3.14.2

* Mon Sep 07 2020 eatdirt <eatdirt> 3.13.5-1.mga8
+ Revision: 1623141
- Upgrade to version 3.13.5

* Fri Sep 04 2020 eatdirt <eatdirt> 3.13.4-1.mga8
+ Revision: 1621463
- imported package petsc

